@@ -18,6 +18,8 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -269,6 +271,8 @@ KafkaSettingsTypeDef = TypedDict(
         "PartitionIncludeSchemaTable": bool,
         "IncludeTableAlterOperations": bool,
         "IncludeControlDetails": bool,
+        "MessageMaxBytes": int,
+        "IncludeNullAndEmpty": bool,
     },
     total=False,
 )
@@ -284,6 +288,7 @@ KinesisSettingsTypeDef = TypedDict(
         "PartitionIncludeSchemaTable": bool,
         "IncludeTableAlterOperations": bool,
         "IncludeControlDetails": bool,
+        "IncludeNullAndEmpty": bool,
     },
     total=False,
 )
